@@ -1,7 +1,5 @@
 """Define NXtomo application and related functions and classes"""
 
-from __future__ import annotations
-
 import logging
 import os
 from copy import deepcopy
@@ -16,6 +14,7 @@ from silx.io.url import DataUrl
 from silx.io.utils import open as hdf5_open
 from silx.utils.proxy import docstring
 
+from nxtomo.geometry._CoordinateSystem import CoordinateSystem
 from nxtomo.nxobject.nxdetector import ImageKey
 from nxtomo.nxobject.nxinstrument import NXinstrument
 from nxtomo.nxobject.nxmonitor import NXmonitor
@@ -25,7 +24,6 @@ from nxtomo.nxobject.utils.decorator import check_dimensionality
 from nxtomo.paths.nxtomo import LATEST_VERSION as LATEST_NXTOMO_VERSION
 from nxtomo.paths.nxtomo import get_paths as get_nexus_paths
 from nxtomo.utils import get_data, get_quantity
-from nxtomo.utils.io import deprecated_warning
 
 _logger = logging.getLogger(__name__)
 
@@ -37,25 +35,18 @@ _ureg = pint.UnitRegistry()
 
 class NXtomo(NXobject):
     """
-    Class defining an NXTomo.
-    His final goal is to save data to disk.
+    Class defining an NXtomo.
+    Its primary goal is to save data to disk.
 
     :param node_name: node_name is used by the NXobject parent to order children when dumping it to file.
-                          has NXtomo is expected to be the highest object in the hierachy. node_name will only be used for saving if no `data_path` is provided when calling 'save' function.
-    :param parent: parent of this NXobject. Most likely None for NXtomo
+        As NXtomo is expected to be the highest object in the hierarchy, node_name will only be used for saving if no `data_path` is provided when calling the `save` function.
+    :param parent: parent of this NXobject. Most likely None for NXtomo.
     """
 
-    def __init__(self, node_name: str = "", parent: NXobject | None = None) -> None:
-        if node_name not in (None, ""):
-            deprecated_warning(
-                type_="parameter",
-                name="node_name",
-                replacement="None - has been removed",
-                since_version="1.1",
-                reason="node_name has been removed to simplify usage. Location must be provided directly in the 'save' function using the 'data_path' parameter",
-            )
+    def __init__(self, parent: NXobject | None = None) -> None:
         super().__init__(node_name="", parent=parent)
         self._set_freeze(False)
+        self._coordinate_system: CoordinateSystem | None = CoordinateSystem.McStas
         self._start_time = None
         self._end_time = None
         self._instrument = NXinstrument(node_name="instrument", parent=self)
@@ -287,6 +278,11 @@ class NXtomo(NXobject):
             nx_dict[f"{self.path}/definition"] = "NXtomo"
             nx_dict[f"{self.path}@version"] = nexus_paths.VERSION
 
+            if self._coordinate_system is not None:
+                nx_dict[f"{self.path}@NeXus_Coordinate_System"] = (
+                    self._coordinate_system.value
+                )
+
         return nx_dict
 
     def detector_data_is_defined_by_url(self) -> bool:
@@ -337,6 +333,12 @@ class NXtomo(NXobject):
                     f"Unable to find nexus version associated with {data_path}@{file_path}"
                 )
                 nexus_version = LATEST_NXTOMO_VERSION
+
+            coordinate_system = root_node.attrs.get("NeXus_Coordinate_System", None)
+            if coordinate_system is not None:
+                coordinate_system = CoordinateSystem(coordinate_system)
+            self._coordinate_system = coordinate_system
+
         nexus_paths = get_nexus_paths(nexus_version)
         self.energy = get_quantity(
             file_path=file_path,
@@ -389,11 +391,11 @@ class NXtomo(NXobject):
     @staticmethod
     def check_consistency(nx_tomo, raises_error: bool = False):
         """
-        Ensure some key datasets have the expected number of value
+        Ensure some key datasets have the expected number of values.
 
-        :param NXtomo nx_tomo: nx_tomo to check
-        :param raises_error: if True then raise ValueError when some incoherent number of value are encounter (if missing will drop a warning only).
-                                  if False then will drop warnings only
+        :param NXtomo nx_tomo: NXtomo to check
+        :param raises_error: if True, raise ValueError when some incoherent number of values is encountered (if missing will drop a warning only).
+            if False, only warnings will be issued.
         """
         if not isinstance(nx_tomo, NXtomo):
             raise TypeError(
@@ -499,9 +501,9 @@ class NXtomo(NXobject):
 
     @staticmethod
     @docstring(NXobject)
-    def concatenate(nx_objects: tuple, node_name=""):
+    def concatenate(nx_objects: tuple):
         """
-        concatenate a tuple of NXobject into a single NXobject
+        Concatenate a tuple of NXobject instances into a single NXobject.
 
         :param nx_objects:
         :return: NXtomo instance which is the concatenation of the nx_objects
@@ -515,7 +517,7 @@ class NXtomo(NXobject):
             if not isinstance(nx_obj, NXtomo):
                 raise TypeError("Cannot concatenate non NXtomo object")
 
-        nx_tomo = NXtomo(node_name)
+        nx_tomo = NXtomo()
 
         # check object concatenation can be handled
         def get_energy() -> pint.Quantity | None:
@@ -738,12 +740,12 @@ class NXtomo(NXobject):
     @staticmethod
     def get_valid_entries(file_path: str) -> tuple:
         """
-        return the list of 'Nxtomo' entries at the root level
+        Return the list of 'NXtomo' entries at the root level.
 
         :param file_path:
-        :return: list of valid Nxtomo node (ordered alphabetically)
+        :return: list of valid NXtomo nodes (ordered alphabetically)
 
-        ..note: entries are sorted to insure consistency
+        .. note: entries are sorted to ensure consistency
         """
         if not os.path.isfile(file_path):
             raise ValueError("given file path should be a file")
@@ -766,7 +768,7 @@ class NXtomo(NXobject):
 
     @staticmethod
     def node_is_nxtomo(node: h5py.Group) -> bool:
-        """check if the given h5py node is an nxtomo node or not"""
+        """Check whether the given h5py node is an NXtomo node."""
         if "NX_class" in node.attrs or "NXclass" in node.attrs:
             _logger.debug(f"{node.name} is recognized as a nx class.")
         else:
@@ -796,17 +798,18 @@ def copy_nxtomo_file(
     vds_resolution="update",
 ):
     """
-    copy one or several NXtomo from a file to another file (solving relative links)
+    Copy one or several NXtomo entries from one file to another (solving relative links).
 
-    :param input_file: nexus file for hich NXtomo have to be copied
-    :param output_file: output file
-    :param entries: entries to be copied. If set to None then all entries will be copied
-    :param overwrite: overwrite data path if already exists
+    :param input_file: NeXus file from which NXtomo entries have to be copied.
+    :param output_file: output file.
+    :param entries: entries to be copied. If set to None then all entries will be copied.
+    :param overwrite: overwrite data path if already exists.
     :param vds_resolution: How to solve virtual datasets. Options are:
-        * update: update Virtual source (relative) paths according to the new location of the file
-        * remove: replace the virtual data source by copying directly the resulting dataset. Warning: in this case all the dataset will be load in memory
-        In the future next option could be:
-        * embed: copy all VDS to new datasets in the output file 'as they are' (avoid to load all the data in memory)
+        * update: update Virtual source (relative) paths according to the new location of the file.
+        * remove: replace the virtual data source by copying directly the resulting dataset. Warning: in this case all the dataset will be loaded in memory.
+
+        In the future another option could be:
+        * embed: copy all VDS to new datasets in the output file 'as they are' (avoid to load all the data in memory).
 
     """
     input_file = os.path.abspath(input_file)
