@@ -1,13 +1,10 @@
 """
-module for handling a `nxdetector <https://manual.nexusformat.org/classes/base_classes/NXdetector.html>`_
+Module for handling an `NXdetector <https://manual.nexusformat.org/classes/base_classes/NXdetector.html>`_.
 """
 
-from __future__ import annotations
-
 import os
 from functools import partial
 from operator import is_not
-from typing import Iterable
 
 import h5py
 import numpy
@@ -27,12 +24,15 @@ from nxtomo.nxobject.nxtransformations import (
     get_ud_flip,
 )
 from nxtomo.nxobject.utils.decorator import check_dimensionality
-from nxtomo.nxobject.utils.ObjectWithPixelSizeMixIn import _ObjectWithPixelSizeMixIn
+from nxtomo.nxobject.utils.ObjectWithPixelSizeMixIn import (
+    _ObjectWithPixelSizeMixIn,
+    check_quantity_consistency,
+)
 from nxtomo.paths.nxtomo import get_paths as get_nexus_path
 from nxtomo.utils import cast_and_check_array_1D, get_data, get_quantity
 from nxtomo.utils.frameappender import FrameAppender
-from nxtomo.utils.io import deprecated, deprecated_warning, ignore_deprecation_warning
-from nxtomo.utils.transformation import DetYFlipTransformation, DetZFlipTransformation
+from nxtomo.utils.io import deprecated, ignore_deprecation_warning
+from nxtomo.utils.transformation import DetXFlipTransformation, DetYFlipTransformation
 
 try:
     from h5py._hl.vds import VDSmap
@@ -56,7 +56,7 @@ _second = _ureg.second
 
 class FOV(_Enum):
     """
-    Possible existing field of view. Use cases are described `here <https://tomotools.gitlab-pages.esrf.fr/tomoscan/language/half_acquisition.html?highlight=half>`_
+    Possible field-of-view values. Use cases are described `here <https://tomotools.gitlab-pages.esrf.fr/tomoscan/language/half_acquisition.html?highlight=half>`_.
 
     """
 
@@ -68,9 +68,9 @@ class FOV(_Enum):
         return FOV(value)
 
     FULL = "Full"
-    """we expect to have the full dataset in the field of view"""
+    """We expect to have the full dataset in the field of view."""
     HALF = "Half"
-    """we expect to have the half of the dataset in the field of view - around 360degree. reconstruction will generate a sinogram of the 'full' dataset"""
+    """We expect to have half of the dataset in the field of view—around 360 degrees. Reconstruction will generate a sinogram of the full dataset."""
 
 
 FieldOfView = FOV
@@ -79,19 +79,19 @@ FieldOfView = FOV
 class ImageKey(_Enum):
     """
     NXdetector `image_key <https://manual.nexusformat.org/classes/base_classes/NXdetector.html#image_key>`_.
-    used to distinguish different frame types.
+    Used to distinguish different frame types.
     """
 
     ALIGNMENT = -1
-    """used for alignment frame (also know as alignement frame)"""
+    """Used for alignment frames (also known as alignment images)."""
     PROJECTION = 0
-    """Projection"""
+    """Projection frames."""
     FLAT_FIELD = 1
-    """flat frame"""
+    """Flat frames."""
     DARK_FIELD = 2
-    """dark frame"""
+    """Dark frames."""
     INVALID = 3
-    """invalid frame (to be ignore during analysis)"""
+    """Invalid frames (ignored during analysis)."""
 
 
 class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
@@ -103,13 +103,13 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
         expected_dim: tuple | None = None,
     ) -> None:
         """
-        representation of `nexus nxdetector <https://manual.nexusformat.org/classes/base_classes/NXdetector.html>`_
+        Representation of `NeXus NXdetector <https://manual.nexusformat.org/classes/base_classes/NXdetector.html>`_.
         Detector of the acquisition.
 
-        :param node_name: name of the detector in the hierarchy
-        :param parent: parent in the nexus hierarchy
-        :param field_of_view: field of view of the detector - if know.
-        :param expected_dim: user can provide expected dimensions as a tuple of int to be checked when data is set
+        :param node_name: name of the detector in the hierarchy.
+        :param parent: parent in the NeXus hierarchy.
+        :param field_of_view: field of view of the detector, if known.
+        :param expected_dim: expected data dimensions, provided as a tuple of ints to be checked when data is set.
         """
         NXobject.__init__(self, node_name=node_name, parent=parent)
         self._set_freeze(False)
@@ -142,8 +142,8 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def data(self) -> numpy.ndarray | tuple | None:
         """
-        detector data (frames).
-        can be None, a numpy array or a list of DataUrl xor h5py Virtual Source
+        Detector data (frames).
+        Can be None, a NumPy array, or a collection of DataUrl or h5py.VirtualSource objects.
         """
         return self._data
 
@@ -181,8 +181,8 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def x_rotation_axis_pixel_position(self) -> float:
         """
-        Absolute position of the Center of Rotation in the detector space in X (X being the abscissa).
-        units: pixel
+        Absolute position of the center of rotation in the detector space in X (X being the abscissa).
+        Units: pixel.
         """
         return self._x_rotation_axis_pixel_position
 
@@ -197,12 +197,12 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def y_rotation_axis_pixel_position(self) -> float:
         """
-        Absolute position of the Center of Rotation in the detector space in Y. (Y being the ordinate)
-        units: pixel
+        Absolute position of the center of rotation in the detector space in Y (Y being the ordinate).
+        Units: pixel.
 
         .. warning::
 
-            This field is not handled at the moment by tomotools. Only x position is handled.
+            This field is not handled at the moment by tomotools. Only the X position is handled.
         """
         return self._y_rotation_axis_pixel_position
 
@@ -214,33 +214,12 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
             )
         self._y_rotation_axis_pixel_position = value
 
-    @property
-    def x_flipped(self):
-        """
-        deprecated: detector image x flip. Use transformation instead
-        """
-        deprecated_warning(
-            type_="property",
-            name="x_flipped",
-            replacement="transformations",
-            since_version="0.13",
-            reason="NXtransformation is the nexus way to handle detector transformation",
-        )
-        return DetZFlipTransformation(flip=True) in self.transformations.transformations
-
-    @x_flipped.setter
-    def x_flipped(self, flipped: bool | None):
-        deprecated_warning(
-            type_="property",
-            name="x_flipped",
-            replacement="transformations",
-            since_version="0.13",
-            reason="NXtransformation is the nexus way to handle detector transformation",
-        )
-        self.set_transformation_from_x_flipped(flipped)
-
+    @deprecated(replacement="set_transformation_from_lr_flipped", since_version="3.0")
     def set_transformation_from_x_flipped(self, flipped: bool | None):
-        """Util function to set transformation from x_flipped simple bool.
+        return self.set_transformation_from_lr_flipped(flipped=flipped)
+
+    def set_transformation_from_lr_flipped(self, flipped: bool | None):
+        """Utility function to set transformations from a simple `x_flipped` boolean ((x in the **detector** coordinate system)).
         Used for backward compatibility and convenience.
         """
         # WARNING: moving from two simple boolean to full NXtransformations make the old API very weak. It should be removed
@@ -255,34 +234,16 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
         for transf in current_lr_transfs:
             self.transformations.rm_transformation(transformation=transf)
 
-        self.transformations.add_transformation(DetZFlipTransformation(flip=flipped))
-
-    @property
-    def y_flipped(self):
-        """
-        deprecated: detector image y flip. Use transformation instead
-        """
-        deprecated_warning(
-            type_="property",
-            name="y_flipped",
-            replacement="transformations",
-            since_version="0.13",
-            reason="NXtransformation is the nexus way to handle detector transformation",
-        )
-        return DetYFlipTransformation(flip=True) in self.transformations.transformations
-
-    @y_flipped.setter
-    def y_flipped(self, flipped: bool):
-        deprecated_warning(
-            type_="property",
-            name="y_flipped",
-            replacement="transformations",
-            since_version="0.13",
-            reason="NXtransformation is the nexus way to handle detector transformation",
-        )
-        self.set_transformation_from_y_flipped(flipped=flipped)
+        self.transformations.add_transformation(DetYFlipTransformation(flip=flipped))
 
+    @deprecated(replacement="set_transformation_from_lr_flipped", since_version="3.0")
     def set_transformation_from_y_flipped(self, flipped: bool | None):
+        return self.set_transformation_from_ud_flipped(flipped=flipped)
+
+    def set_transformation_from_ud_flipped(self, flipped: bool | None):
+        """
+        Util function to set a detector transformation (y in the **detector** coordinate system).
+        """
         # WARNING: moving from two simple boolean to full NXtransformations make the old API very weak. It should be removed
         # soon (but we want to keep the API for at least one release). This is expected to fail except if you stick to {x,y} flips
         if isinstance(flipped, numpy.bool_):
@@ -296,7 +257,7 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
         for transf in current_ud_transfs:
             self.transformations.rm_transformation(transf)
 
-        self.transformations.add_transformation(DetYFlipTransformation(flip=flipped))
+        self.transformations.add_transformation(DetXFlipTransformation(flip=flipped))
 
     @property
     def distance(self) -> pint.Quantity | None:
@@ -313,7 +274,7 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def field_of_view(self) -> FieldOfView | None:
         """
-        detector :class:`~nxtomo.nxobject.nxdetector.FieldOfView`
+        Detector :class:`~nxtomo.nxobject.nxdetector.FieldOfView`.
         """
         return self._field_of_view
 
@@ -340,7 +301,7 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     )
     def estimated_cor_from_motor(self) -> float | None:
         """
-        hint of center of rotation in pixel read from motor (when possible)
+        Hint of the center of rotation in pixels read from the motor (when possible).
         """
         return self._x_rotation_axis_pixel_position
 
@@ -356,12 +317,15 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def image_key_control(self) -> numpy.ndarray | None:
         """
-        :class:`~nxtomo.nxobject.nxdetector.ImageKey` for each frames
+        :class:`~nxtomo.nxobject.nxdetector.ImageKey` for each frame.
         """
         return self._image_key_control
 
     @image_key_control.setter
-    def image_key_control(self, control_image_key: Iterable | None):
+    def image_key_control(
+        self,
+        control_image_key: list | tuple | numpy.ndarray | None,
+    ):
         control_image_key = cast_and_check_array_1D(
             control_image_key, "control_image_key"
         )
@@ -376,7 +340,9 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def image_key(self) -> numpy.ndarray | None:
         """
-        :class:`~nxtomo.nxobject.nxdetector.ImageKey` for each frames. Replace all :class:`~nxtomo.nxobject,nxdetector.ImageKey.ALIGNMENT` by :class:`~nxtomo.nxobject,nxdetector.ImageKey.PROJECTION` to fulfil nexus standard
+        :class:`~nxtomo.nxobject.nxdetector.ImageKey` for each frame. Replace all
+        :class:`~nxtomo.nxobject.nxdetector.ImageKey.ALIGNMENT` values with
+        :class:`~nxtomo.nxobject.nxdetector.ImageKey.PROJECTION` to fulfill the NeXus standard.
         """
         if self.image_key_control is None:
             return None
@@ -390,7 +356,7 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def tomo_n(self) -> int | None:
         """
-        expected number of :class:`~nxtomo.nxobject,nxdetector.ImageKey.PROJECTION` frames
+        Expected number of :class:`~nxtomo.nxobject.nxdetector.ImageKey.PROJECTION` frames.
         """
         return self._tomo_n
 
@@ -401,7 +367,7 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def group_size(self) -> int | None:
         """
-        number of acquisition for the dataset
+        Number of acquisitions for the dataset.
         """
         return self._group_size
 
@@ -412,7 +378,7 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def roi(self) -> tuple | None:
         """
-        detector region of interest as x0,y0,x1,y1
+        Detector region of interest as (x0, y0, x1, y1).
         """
         return self._roi
 
@@ -652,14 +618,22 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
                             ) = vs_info.src_space.get_regular_hyperslab()
                             source_end = source_start[0] + length
 
+                            vs_slice = slice(source_start[0], source_end)
                             sel = selection.select(
                                 dataset.shape,
-                                slice(source_start[0], source_end),
+                                vs_slice,
                                 dataset=dataset,
                             )
                             virtual_source.sel = sel
+                        else:
+                            vs_slice = None
 
-                        urls.append(from_virtual_source_to_data_url(virtual_source))
+                        urls.append(
+                            from_virtual_source_to_data_url(
+                                virtual_source,
+                                vs_slice=vs_slice,
+                            )
+                        )
                 else:
                     urls = [
                         DataUrl(
@@ -709,14 +683,14 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
 
         # TODO Henri: create a function without the warning for the backward compatibility
         if nexus_detector_paths.X_FLIPPED is not None:
-            self.set_transformation_from_x_flipped(
+            self.set_transformation_from_lr_flipped(
                 get_data(
                     file_path=file_path,
                     data_path="/".join([data_path, nexus_detector_paths.X_FLIPPED]),
                 )
             )
         if nexus_detector_paths.Y_FLIPPED is not None:
-            self.set_transformation_from_y_flipped(
+            self.set_transformation_from_ud_flipped(
                 get_data(
                     file_path=file_path,
                     data_path="/".join([data_path, nexus_detector_paths.Y_FLIPPED]),
@@ -801,8 +775,9 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
         file_path: str, data_path: str, nexus_version
     ) -> NXtransformations | None:
         """
-        as transformations is not a fixed position try to load it from the default location ('transformations') else browse
-        all HDF5 groups to retrieve an NXTransformations group
+        Transformations are not stored at a fixed position: try to load them from
+        the default location ('transformations'); otherwise, browse all HDF5 groups
+        to retrieve an NXtransformations group.
         """
         nexus_paths = get_nexus_path(nexus_version)
         nexus_detector_paths = nexus_paths.nx_detector_paths
@@ -876,12 +851,12 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
                     f"found different NXTransformations. ({nx_detector.transformations.to_nx_dict()} vs {nx_obj.transformations.to_nx_dict()}). Pick the first one"
                 )
 
-            if nx_detector.distance is not None and not numpy.isclose(
-                nx_detector.distance.magnitude, nx_obj.distance.magnitude
-            ):
-                _logger.warning(
-                    f"found different distance value. ({nx_detector.distance.magnitude} vs {nx_obj.distance.magnitude}). Pick the first one"
-                )
+            check_quantity_consistency(
+                reference=nx_detector.distance,
+                candidate=nx_obj.distance,
+                label="detector distance",
+                logger=_logger,
+            )
             if (
                 nx_detector.field_of_view
                 and nx_detector.field_of_view != nx_obj.field_of_view
@@ -919,7 +894,7 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
             if isinstance(detector_data[0], numpy.ndarray):
                 # store_as = "as_numpy_array"
                 expected = numpy.ndarray
-            elif isinstance(detector_data[0], Iterable):
+            elif isinstance(detector_data[0], (list, tuple)):
                 if isinstance(detector_data[0][0], h5py.VirtualSource):
                     # store_as = "as_virtual_source"
                     expected = h5py.VirtualSource
@@ -958,7 +933,8 @@ class NXdetector(NXobject, _ObjectWithPixelSizeMixIn):
     @property
     def transformations(self):
         """
-        `NXtransformation <https://manual.nexusformat.org/classes/base_classes/NXtransformations.html>`_ of detector (image flip, manual rotation of the detector...)
+        `NXtransformation <https://manual.nexusformat.org/classes/base_classes/NXtransformations.html>`_
+        objects describing detector flips or manual rotations.
         """
         return self._transformations
 
@@ -984,7 +960,7 @@ class NXdetectorWithUnit(NXdetector):
     def data(self) -> pint.Quantity | None:
         """
         Detector data.
-        Can be a numpy array, list of DataUrl, VirtualSource, or a pint.Quantity.
+        Can be a NumPy array, list of DataUrl objects, VirtualSource instances, or a pint.Quantity.
         """
         return self._data
 
@@ -1105,7 +1081,7 @@ class NXdetectorWithUnit(NXdetector):
             expected = pint.Quantity
         elif isinstance(first_data, numpy.ndarray):
             expected = numpy.ndarray
-        elif isinstance(first_data, Iterable):
+        elif isinstance(first_data, (list, tuple)):
             if isinstance(first_data[0], h5py.VirtualSource):
                 expected = h5py.VirtualSource
             elif isinstance(first_data[0], DataUrl):
