@@ -1,9 +1,7 @@
 """
-module for handling a `nxinstrument <https://manual.nexusformat.org/classes/base_classes/NXinstrument.html>`_
+Module for handling an `NXinstrument <https://manual.nexusformat.org/classes/base_classes/NXinstrument.html>`_.
 """
 
-from __future__ import annotations
-
 import logging
 from functools import partial
 from operator import is_not
@@ -33,12 +31,12 @@ class NXinstrument(NXobject):
         self, node_name: str = "instrument", parent: NXobject | None = None
     ) -> None:
         """
-        representation of `nexus NXinstrument <https://manual.nexusformat.org/classes/base_classes/NXinstrument.html>`_.
+        Representation of `NeXus NXinstrument <https://manual.nexusformat.org/classes/base_classes/NXinstrument.html>`_.
 
         Collection of the components of the instrument or beamline.
 
-        :param node_name: name of the detector in the hierarchy
-        :param parent: parent in the nexus hierarchy
+        :param node_name: name of the instrument in the hierarchy.
+        :param parent: parent in the NeXus hierarchy.
         """
         super().__init__(node_name=node_name, parent=parent)
         self._set_freeze(False)
@@ -91,7 +89,7 @@ class NXinstrument(NXobject):
     @property
     def source(self) -> NXsource | None:
         """
-        :class:`~nxtomo.nxobject.nxdetector.NXsource`
+        :class:`~nxtomo.nxobject.nxsource.NXsource`
         """
         return self._source
 
@@ -105,7 +103,7 @@ class NXinstrument(NXobject):
 
     @property
     def name(self) -> str | None:
-        """instrument name like BM00"""
+        """Instrument name (for example, BM00)."""
         return self._name
 
     @name.setter
@@ -156,7 +154,7 @@ class NXinstrument(NXobject):
         detector_data_as: str,
     ) -> NXobject:
         """
-        Create and load an NXsample from data on disk
+        Create and load an NXinstrument from data on disk.
         """
         nexus_paths = get_nexus_paths(nexus_version)
         nexus_instrument_paths = nexus_paths.nx_instrument_paths
