@@ -1,9 +1,7 @@
 """
-module for handling a `nxmonitor <https://manual.nexusformat.org/classes/base_classes/NXmonitor.html>`_
+Module for handling an `NXmonitor <https://manual.nexusformat.org/classes/base_classes/NXmonitor.html>`_.
 """
 
-from __future__ import annotations
-
 from functools import partial
 from operator import is_not
 
@@ -26,11 +24,11 @@ _ampere = _ureg.ampere
 class NXmonitor(NXobject):
     def __init__(self, node_name="control", parent: NXobject | None = None) -> None:
         """
-        representation of `nexus NXmonitor <https://manual.nexusformat.org/classes/base_classes/NXmonitor.html>`_.
+        Representation of `NeXus NXmonitor <https://manual.nexusformat.org/classes/base_classes/NXmonitor.html>`_.
         A monitor of incident beam data.
 
-        :param node_name: name of the detector in the hierarchy
-        :param parent: parent in the nexus hierarchy
+        :param node_name: name of the monitor in the hierarchy.
+        :param parent: parent in the NeXus hierarchy.
         """
         super().__init__(node_name=node_name, parent=parent)
         self._set_freeze(False)
@@ -41,7 +39,7 @@ class NXmonitor(NXobject):
     def data(self) -> pint.Quantity | None:
         """
         Monitor data.
-        In the case of NXtomo, it expects to contain machine electric current for each frame.
+        In the case of NXtomo, it is expected to contain the machine electric current for each frame.
         """
         return self._data
 
@@ -87,7 +85,7 @@ class NXmonitor(NXobject):
 
     def _load(self, file_path: str, data_path: str, nexus_version: float) -> NXobject:
         """
-        Create and load an NXmonitor from data on disk
+        Create and load an NXmonitor from data on disk.
         """
         nexus_paths = get_nexus_paths(nexus_version)
         monitor_nexus_paths = nexus_paths.nx_monitor_paths
