@@ -1,9 +1,7 @@
 """
-module for handling a `nxsample <https://manual.nexusformat.org/classes/base_classes/NXsample.html>`_
+Module for handling an `NXsample <https://manual.nexusformat.org/classes/base_classes/NXsample.html>`_.
 """
 
-from __future__ import annotations
-
 import logging
 from functools import partial
 from operator import is_not
@@ -34,11 +32,11 @@ _degree = _ureg.degree
 class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
     def __init__(self, node_name="sample", parent: NXobject | None = None) -> None:
         """
-        representation of `nexus NXsample <https://manual.nexusformat.org/classes/base_classes/NXsample.html>`_.
-        A monitor of incident beam data.
+        Representation of `NeXus NXsample <https://manual.nexusformat.org/classes/base_classes/NXsample.html>`_.
+        Metadata describing the sample.
 
-        :param node_name: name of the detector in the hierarchy
-        :param parent: parent in the nexus hierarchy
+        :param node_name: name of the sample in the hierarchy.
+        :param parent: parent in the NeXus hierarchy.
         """
         NXobject.__init__(self, node_name=node_name, parent=parent)
         self._set_freeze(False)
@@ -55,7 +53,7 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
 
     @property
     def name(self) -> str | None:
-        """sample name"""
+        """Sample name."""
         return self._name
 
     @name.setter
@@ -66,7 +64,7 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
 
     @property
     def rotation_angle(self) -> pint.Quantity | None:
-        """sample rotation angle. One per frame"""
+        """Sample rotation angle (one value per frame)."""
         return self._rotation_angle
 
     @rotation_angle.setter
@@ -76,7 +74,7 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
 
     @property
     def x_translation(self) -> pint.Quantity | None:
-        """sample translation along x. See `modelling at esrf <https://tomo.gitlab-pages.esrf.fr/ebs-tomo/master/modelization.html>`_ for more information"""
+        """Sample translation along X. See `modelling at ESRF <https://tomo.gitlab-pages.esrf.fr/ebs-tomo/master/modelization.html>`_ for more information."""
         return self._x_translation
 
     @x_translation.setter
@@ -86,7 +84,7 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
 
     @property
     def y_translation(self) -> pint.Quantity | None:
-        """sample translation along y. See `modelling at esrf <https://tomo.gitlab-pages.esrf.fr/ebs-tomo/master/modelization.html>`_ for more information"""
+        """Sample translation along Y. See `modelling at ESRF <https://tomo.gitlab-pages.esrf.fr/ebs-tomo/master/modelization.html>`_ for more information."""
         return self._y_translation
 
     @y_translation.setter
@@ -96,7 +94,7 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
 
     @property
     def z_translation(self) -> pint.Quantity | None:
-        """sample translation along z. See `modelling at esrf <https://tomo.gitlab-pages.esrf.fr/ebs-tomo/master/modelization.html>`_ for more information"""
+        """Sample translation along Z. See `modelling at ESRF <https://tomo.gitlab-pages.esrf.fr/ebs-tomo/master/modelization.html>`_ for more information."""
         return self._z_translation
 
     @z_translation.setter
@@ -115,7 +113,7 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
 
     @property
     def transformations(self) -> tuple[NXtransformations]:
-        """detector transformations as `NXtransformations <https://manual.nexusformat.org/classes/base_classes/NXtransformations.html>`_"""
+        """Sample transformations as `NXtransformations <https://manual.nexusformat.org/classes/base_classes/NXtransformations.html>`_."""
         return self._transformations
 
     @transformations.setter
@@ -160,7 +158,9 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
             nx_dict[path_name] = self.name
         if self.rotation_angle is not None:
             path_rotation_angle = f"{self.path}/{nexus_sample_paths.ROTATION_ANGLE}"
-            nx_dict[path_rotation_angle] = self.rotation_angle
+            nx_dict[path_rotation_angle] = self.rotation_angle.to(
+                _ureg.degree
+            ).magnitude
             nx_dict["@".join([path_rotation_angle, "units"])] = "degree"
         if self.x_translation is not None:
             path_x_translation = f"{self.path}/{nexus_sample_paths.X_TRANSLATION}"
@@ -199,7 +199,7 @@ class NXsample(NXobject, _ObjectWithPixelSizeMixIn):
 
     def _load(self, file_path: str, data_path: str, nexus_version: float) -> NXobject:
         """
-        Create and load an NXsample from data on disk
+        Create and load an NXsample from data on disk.
         """
         nexus_paths = get_nexus_paths(nexus_version)
         nexus_sample_paths = nexus_paths.nx_sample_paths
