@@ -1,9 +1,7 @@
 """
-module for handling a `nxsource <https://manual.nexusformat.org/classes/base_classes/NXsource.html>`_
+Module for handling an `NXsource <https://manual.nexusformat.org/classes/base_classes/NXsource.html>`_.
 """
 
-from __future__ import annotations
-
 import logging
 from functools import partial
 from operator import is_not
@@ -28,7 +26,7 @@ _meter = _ureg.meter
 
 class SourceType(_Enum):
     """
-    source types like 'Synchrotron X-ray Source' or 'Free-Electron Laser'
+    Source types like "Synchrotron X-ray Source" or "Free-Electron Laser".
     """
 
     SPALLATION_NEUTRON = "Spallation Neutron Source"
@@ -48,7 +46,7 @@ class SourceType(_Enum):
 
 class ProbeType(_Enum):
     """
-    probe type like 'x-ray' or 'neutron'
+    Probe types like "x-ray" or "neutron".
     """
 
     NEUTRON = "neutron"
@@ -62,7 +60,7 @@ class ProbeType(_Enum):
 
 
 class NXsource(NXobject):
-    """Information regarding the x-ray storage ring/facility"""
+    """Information regarding the X-ray storage ring or facility."""
 
     def __init__(
         self,
@@ -73,14 +71,14 @@ class NXsource(NXobject):
         probe=None,
     ):
         """
-        representation of `nexus NXsource <https://manual.nexusformat.org/classes/base_classes/NXsource.html>`_.
-        The neutron or x-ray storage ring/facility.
+        Representation of `NeXus NXsource <https://manual.nexusformat.org/classes/base_classes/NXsource.html>`_.
+        The neutron or X-ray storage ring or facility.
 
-        :param node_name: name of the detector in the hierarchy
-        :param parent: parent in the nexus hierarchy
-        :param source_name: name of the source
-        :param source_type: source type
-        :param probe: probe
+        :param node_name: name of the source in the hierarchy.
+        :param parent: parent in the NeXus hierarchy.
+        :param source_name: name of the source.
+        :param source_type: source type.
+        :param probe: probe.
         """
         super().__init__(node_name=node_name, parent=parent)
         self._set_freeze(False)
@@ -88,13 +86,13 @@ class NXsource(NXobject):
         self._type = source_type
         self._probe = probe
         self._distance = None
-        """source / sample distance"""
+        """Source / sample distance."""
         self._set_freeze(True)
 
     @property
     def name(self) -> None | str:
         """
-        source name
+        Source name.
         """
         return self._name
 
@@ -114,7 +112,7 @@ class NXsource(NXobject):
     @property
     def type(self) -> SourceType | None:
         """
-        source type as :class:`~nxtomo.nxobject.nxsource.SourceType`
+        Source type as :class:`~nxtomo.nxobject.nxsource.SourceType`.
         """
         return self._type
 
@@ -129,7 +127,7 @@ class NXsource(NXobject):
     @property
     def probe(self) -> ProbeType | None:
         """
-        probe as :class:`~nxtomo.nxobject.nxsource.ProbeType`
+        Probe as :class:`~nxtomo.nxobject.nxsource.ProbeType`.
         """
         return self._probe
 
@@ -241,7 +239,7 @@ class NXsource(NXobject):
 
 class DefaultESRFSource(NXsource):
     """
-    ESRF source
+    ESRF source.
     """
 
     def __init__(self, node_name="source", parent=None) -> None:
