@@ -1,9 +1,7 @@
 """
-module for handling a `nxtransformations <https://manual.nexusformat.org/classes/base_classes/nxtransformations.html#nxtransformations>`_
+Module for handling an `NXtransformations <https://manual.nexusformat.org/classes/base_classes/nxtransformations.html#nxtransformations>`_ group.
 """
 
-from __future__ import annotations
-
 import logging
 from copy import deepcopy
 
@@ -31,12 +29,12 @@ __all__ = ["NXtransformations", "get_lr_flip", "get_ud_flip"]
 class NXtransformations(NXobject):
     def __init__(self, node_name: str = "transformations", parent=None) -> None:
         """
-        Collection of axis-based translations and rotations to describe a geometry
+        Collection of axis-based translations and rotations to describe a geometry.
 
-        For tomotools the first usage would be to allow users to provide more metadata to tag acquisition (like 'detector has been rotate' of 90 degree...)
+        For tomotools the first usage would be to allow users to provide more metadata to tag acquisitions (like "detector has been rotated" by 90 degrees).
 
-        :param node_name: name of the detector in the hierarchy
-        :param parent: parent in the nexus hierarchy
+        :param node_name: name of the transformations group in the hierarchy.
+        :param parent: parent in the NeXus hierarchy.
         """
         super().__init__(node_name, parent)
         self._set_freeze(False)
@@ -47,14 +45,14 @@ class NXtransformations(NXobject):
     @property
     def transformations(self) -> tuple:
         """
-        return dict with str as key and Transformation as value
+        Return the registered transformations as a tuple.
         """
         return tuple(self._transformations.values())
 
     @transformations.setter
     def transformations(self, transformations: tuple):
         """
-        :param transformations: dict as [str, Transformation]
+        :param transformations: tuple of Transformation instances
         """
         # check type
         if not isinstance(transformations, (tuple, list)):
@@ -82,12 +80,12 @@ class NXtransformations(NXobject):
         self, transformation: Transformation, overwrite=False, skip_if_exists=False
     ):
         """
-        add a transformation to the existing one.
+        Add a transformation to the existing ones.
 
         :param transformation: transformation to be added
         :param overwrite: if a transformation with the same axis_name already exists then overwrite it
         :param skip_if_exists: if a transformation with the same axis_name already exists then keep the existing one
-        :raises: KeyError, if a transformation with the same axis_name already registered
+        :raises: KeyError, if a transformation with the same axis_name is already registered
         """
         if skip_if_exists is overwrite is True:
             raise ValueError(
@@ -116,9 +114,9 @@ class NXtransformations(NXobject):
 
     def rm_transformation(self, transformation: Transformation):
         """
-        remove the provided transformation from the list of existing transformations
+        Remove the provided transformation from the list of existing transformations.
 
-        :param transformation: Transformation to be removed
+        :param transformation: transformation to be removed
         """
         self._transformations.pop(transformation.axis_name, None)
 
@@ -159,7 +157,10 @@ class NXtransformations(NXobject):
             if len(transformations_needing_gravity) > 0:
                 gravity = GravityTransformation()
                 gravity_name = gravity.axis_name
-                if gravity_name in transformations.keys():
+                if (
+                    gravity_name in transformations.keys()
+                    and transformations[gravity_name] != gravity
+                ):
                     _logger.warning(
                         f"transformations already contains a transformation named '{gravity.axis_name}'. Unable to expand transformation chain (cannot append gravity twice)"
                     )
@@ -223,7 +224,7 @@ class NXtransformations(NXobject):
         self, file_path: str, data_path: str, nexus_version: float | None
     ) -> NXobject:
         """
-        Create and load an NXmonitor from data on disk.
+        Create and load an NXtransformations group from data on disk.
         """
         nexus_paths = get_nexus_paths(nexus_version)
         transformations_nexus_paths = nexus_paths.nx_transformations_paths
