@@ -1,9 +1,7 @@
 """
-module for NXobject shared classes
+Shared mixins for NXobject pixel size handling.
 """
 
-from __future__ import annotations
-
 import logging
 
 import numpy
@@ -19,7 +17,7 @@ _ureg = pint.get_application_registry()
 
 class _ObjectWithPixelSizeMixIn:
     """
-    Class to be shared by NXobject that can define a pixel size
+    Class to be shared by NXobject classes that can define a pixel size.
     """
 
     def __init__(self):
@@ -31,8 +29,8 @@ class _ObjectWithPixelSizeMixIn:
     @property
     def x_pixel_size(self) -> pint.Quantity | None:
         """
-        x pixel size as a field with a unit (get a value and a unit - default unit is SI).
-        Know as 'x sample pixel size' in some application
+        X pixel size stored as a quantity with units (default unit is SI).
+        Known as the "X sample pixel size" in some applications.
         """
         return self._x_pixel_size
 
@@ -47,8 +45,8 @@ class _ObjectWithPixelSizeMixIn:
     @property
     def y_pixel_size(self) -> pint.Quantity | None:
         """
-        y pixel size as a field with a unit (get a value and a unit - default unit is SI).
-        Know as 'y sample pixel size' in some application
+        Y pixel size stored as a quantity with units (default unit is SI).
+        Known as the "Y sample pixel size" in some applications.
         """
         return self._y_pixel_size
 
@@ -117,7 +115,7 @@ class _ObjectWithPixelSizeMixIn:
     @staticmethod
     def concatenate(output_nx_object, nx_objects: tuple):
         """
-        Update output_nx_object (expected to be the inheriting class) with the pixel size from 'nx_objects'
+        Update `output_nx_object` (expected to be the inheriting class) with the pixel size from `nx_objects`.
         """
         if not isinstance(output_nx_object, _ObjectWithPixelSizeMixIn):
             raise TypeError
@@ -126,15 +124,43 @@ class _ObjectWithPixelSizeMixIn:
         output_nx_object.x_pixel_size = nx_objects[0].x_pixel_size
         output_nx_object.y_pixel_size = nx_objects[0].y_pixel_size
         for nx_obj in nx_objects[1:]:
-            if output_nx_object.x_pixel_size is not None and not numpy.isclose(
-                output_nx_object.x_pixel_size, nx_obj.x_pixel_size
-            ):
-                _logger.warning(
-                    f"found different x pixel size value. ({output_nx_object.x_pixel_size} vs {nx_obj.x_pixel_size}). Pick the first one"
-                )
-            if output_nx_object.y_pixel_size is not None and not numpy.isclose(
-                output_nx_object.y_pixel_size, nx_obj.y_pixel_size
-            ):
-                _logger.warning(
-                    f"found different y pixel size value. ({output_nx_object.y_pixel_size} vs {nx_obj.y_pixel_size}). Pick the first one"
-                )
+            check_quantity_consistency(
+                reference=output_nx_object.x_pixel_size,
+                candidate=nx_obj.x_pixel_size,
+                label="x pixel size",
+                logger=_logger,
+            )
+            check_quantity_consistency(
+                reference=output_nx_object.y_pixel_size,
+                candidate=nx_obj.y_pixel_size,
+                label="y pixel size",
+                logger=_logger,
+            )
+
+
+def check_quantity_consistency(
+    reference: pint.Quantity | None,
+    candidate: pint.Quantity | None,
+    label: str,
+    logger: logging.Logger,
+) -> None:
+    """
+    Compare two pint quantities and warn (or raise) when they differ.
+
+    :param reference: quantity selected for the output object.
+    :param candidate: quantity originating from the object being merged.
+    :param label: human-readable label used in warning messages.
+    :param logger: logger used to emit warnings.
+    """
+    if reference is None or candidate is None:
+        return
+
+    candidate_in_reference_unit = candidate.to(reference.units)
+
+    if not numpy.isclose(reference.magnitude, candidate_in_reference_unit.magnitude):
+        logger.warning(
+            "found different %s value. (%s vs %s). Pick the first one",
+            label,
+            reference,
+            candidate,
+        )
