@@ -1,9 +1,7 @@
 """
-Some internal utils decorator
+Internal decorator utilities.
 """
 
-from __future__ import annotations
-
 from functools import wraps
 
 import pint
@@ -16,7 +14,7 @@ def check_dimensionality(expected_dimension: str, allow_none: bool = True):
     """
     Decorator to check the dimensionality of a pint.Quantity parameter.
 
-    :param expected_dimension: expected dimensionality of the parameter. Like [None, [lenght]]
+    :param expected_dimension: expected dimensionality of the parameter, e.g. "[length]".
     """
 
     def check_parameter(parameter, parameter_name: str, allow_none: bool):
