@@ -1,6 +1,4 @@
-"""module to provide helper classes to define transformations contained in NXtransformations"""
-
-from __future__ import annotations
+"""Helper classes to define transformations contained in NXtransformations."""
 
 import logging
 
@@ -8,8 +6,6 @@ import numpy
 import pint
 from silx.utils.enum import Enum as _Enum
 
-from nxtomo.utils.io import deprecated_warning
-
 # Create a pint unit registry
 _ureg = pint.UnitRegistry()
 _degree = _ureg.degree
@@ -23,10 +19,9 @@ __all__ = [
     "TransformationType",
     "TransformationAxis",
     "Transformation",
+    "DetXFlipTransformation",
     "DetYFlipTransformation",
-    "UDDetTransformation",
     "DetZFlipTransformation",
-    "LRDetTransformation",
     "GravityTransformation",
     "get_lr_flip",
     "get_ud_flip",
@@ -36,7 +31,7 @@ __all__ = [
 
 class TransformationType(_Enum):
     """
-    possible NXtransformations types
+    Possible NXtransformations types.
     """
 
     TRANSLATION = "translation"
@@ -46,8 +41,8 @@ class TransformationType(_Enum):
 
 class TransformationAxis:
     """
-    Some predefined axis for tomography acquisition done at esrf.
-    Warning: these are stored as (X, Y, Z) and not under the usual numpy reference (Z, Y, X)
+    Predefined axes for tomography acquisitions performed at ESRF.
+    Warning: these are stored as (X, Y, Z) and not under the usual NumPy reference (Z, Y, X).
 
     See: https://tomo.gitlab-pages.esrf.fr/ebs-tomo/master/modelization.html
     """
@@ -59,13 +54,13 @@ class TransformationAxis:
 
 class Transformation:
     """
-    Define a Transformation done on an axis.
+    Define a transformation applied along an axis.
 
     :param axis_name: name of the transformation.
-    :param transformation_type: type of the transformation. (Once created the type should not change.)
-    :param vector: vector of the transformation. Expected as a tuple of three values or an instance of TransformationAxis.
+    :param transformation_type: type of the transformation (the type should not change once created).
+    :param vector: transformation vector as a tuple of three values or an instance of TransformationAxis.
     :param depends_on: name of another transformation on which this transformation depends.
-    :warning: For rotations, a value given in radians is automatically converted to degree when comparing.
+    .. warning:: For rotations, values given in radians are automatically converted to degrees when comparing.
     """
 
     __isfrozen = False
@@ -440,9 +435,25 @@ class Transformation:
         )
 
 
+class DetXFlipTransformation(Transformation):
+    """
+    Convenient class to a flip with X (1, 0, 0) as the rotation axis.
+    """
+
+    def __init__(self, flip: bool, axis_name="rx", depends_on=None) -> None:
+        value = 180 if flip else 0
+        super().__init__(
+            axis_name=axis_name,
+            value=value * _degree,
+            transformation_type=TransformationType.ROTATION,
+            vector=TransformationAxis.AXIS_X,
+            depends_on=depends_on,
+        )
+
+
 class DetYFlipTransformation(Transformation):
     """
-    Convenient class to define a detector up-down flip (assuming the detector center is at (0, 0)).
+    Convenient class to a flip with Y (0, 1, 0) as the rotation axis.
     """
 
     def __init__(self, flip: bool, axis_name="ry", depends_on=None) -> None:
@@ -456,21 +467,9 @@ class DetYFlipTransformation(Transformation):
         )
 
 
-class UDDetTransformation(DetYFlipTransformation):
-    def __init__(self, axis_name="ry", depends_on=None, value=180):
-        deprecated_warning(
-            type_="class",
-            name="UDDetTransformation",
-            replacement="DetYFlipTransformation",
-            since_version="1.3",
-            reason="Detector rotation can now be 0 degree.",
-        )
-        super().__init__(flip=True, axis_name=axis_name, depends_on=depends_on)
-
-
 class DetZFlipTransformation(Transformation):
     """
-    Convenient class to define a detector left-right flip.
+    Convenient class to a flip with Z (0, 0, 1) as the rotation axis.
     """
 
     def __init__(self, flip: bool, axis_name="rz", depends_on=None) -> None:
@@ -484,23 +483,11 @@ class DetZFlipTransformation(Transformation):
         )
 
 
-class LRDetTransformation(DetZFlipTransformation):
-    def __init__(self, axis_name="rz", depends_on=None, value=180):
-        deprecated_warning(
-            type_="class",
-            name="LRDetTransformation",
-            replacement="DetZFlipTransformation",
-            since_version="1.3",
-            reason="Detector rotation can now be 0 degree.",
-        )
-        super().__init__(flip=True, axis_name=axis_name, depends_on=depends_on)
-
-
 class GravityTransformation(Transformation):
     """
     Gravity is used to solve the transformation chain (acting as the chain endpoint).
-    The direction is set to -Z.
-    The dimension will be unitless since we use it to solve the transformation chain.
+    The direction is set to -Z, and the dimension is unitless because it is used to
+    resolve the transformation chain.
     """
 
     def __init__(self) -> None:
@@ -514,27 +501,7 @@ class GravityTransformation(Transformation):
 
 def get_lr_flip(transformations: tuple) -> tuple:
     """
-    Check among all transformations for those matching a left-right detector flip.
-    Return a tuple with all matching transformations.
-    """
-    if not isinstance(transformations, (tuple, list)):
-        raise TypeError(
-            f"transformations is expected to be a tuple. {type(transformations)} provided"
-        )
-    res = []
-    for transformation in transformations:
-        if transformation in (
-            DetZFlipTransformation(flip=True),
-            DetZFlipTransformation(flip=False),
-        ):
-            res.append(transformation)
-    return tuple(res)
-
-
-def get_ud_flip(transformations: tuple) -> tuple:
-    """
-    Check among all transformations for those matching an up-down detector flip.
-    Return a tuple with all matching transformations.
+    Check all transformations for those matching a left-right detector flip and return them.
     """
     if not isinstance(transformations, (tuple, list)):
         raise TypeError(
@@ -550,6 +517,24 @@ def get_ud_flip(transformations: tuple) -> tuple:
     return tuple(res)
 
 
+def get_ud_flip(transformations: tuple) -> tuple:
+    """
+    Check all transformations for those matching an up-down detector flip and return them.
+    """
+    if not isinstance(transformations, (tuple, list)):
+        raise TypeError(
+            f"transformations is expected to be a tuple. {type(transformations)} provided"
+        )
+    res = []
+    for transformation in transformations:
+        if transformation in (
+            DetXFlipTransformation(flip=True),
+            DetXFlipTransformation(flip=False),
+        ):
+            res.append(transformation)
+    return tuple(res)
+
+
 def build_matrix(transformations: set):
     """
     Build a matrix from a set of Transformations.
