@@ -1,9 +1,6 @@
-"""general utils"""
-
-from __future__ import annotations
+"""General utility helpers."""
 
 import os
-from typing import Iterable
 
 import h5py
 import numpy
@@ -33,17 +30,17 @@ __all__ = [
 
 def cast_and_check_array_1D(array, array_name: str):
     """
-    Cast provided array to 1D and handle pint quantities.
+    Cast the provided array to 1D and handle pint quantities.
 
-    :param array: Array to be cast to 1D. Can be a pint.Quantity.
-    :param array_name: Name of the array - used for logging only.
-    :returns: 1D NumPy array (with magnitude if a pint.Quantity)
-    :raises TypeError: If input type is invalid.
-    :raises ValueError: If input has more than 1 dimension.
+    :param array: array to be cast to 1D. Can be a pint.Quantity.
+    :param array_name: name of the array (used for logging only).
+    :return: 1D NumPy array (with magnitude if a pint.Quantity).
+    :raises TypeError: if the input type is invalid.
+    :raises ValueError: if the input has more than one dimension.
     """
-    if not isinstance(array, (type(None), numpy.ndarray, Iterable, pint.Quantity)):
+    if not isinstance(array, (type(None), numpy.ndarray, tuple, list, pint.Quantity)):
         raise TypeError(
-            f"{array_name} is expected to be None, an Iterable, or a pint.Quantity. "
+            f"{array_name} is expected to be None, a numpy.ndarray, a tuple, a list, or a pint.Quantity. "
             f"Not {type(array)}"
         )
     if isinstance(array, pint.Quantity):
@@ -64,12 +61,12 @@ def get_quantity(
     file_path: str, data_path: str, default_unit: pint.Unit
 ) -> pint.Quantity:
     """
-    Return the value and unit of an HDF5 dataset. If the unit is not found, fallback on 'default_unit'.
+    Return the value and unit of an HDF5 dataset. If the unit is not found, fall back on `default_unit`.
 
-    :param file_path: File path location of the HDF5 dataset to read.
-    :param data_path: Data path location of the HDF5 dataset to read.
-    :param default_unit: Default unit to fall back on if the dataset has no 'unit' or 'units' attribute as a pint.Unit object.
-    :return: A pint.Quantity with the data and associated unit.
+    :param file_path: file path location of the HDF5 dataset to read.
+    :param data_path: data path location of the HDF5 dataset to read.
+    :param default_unit: default unit to use if the dataset has no ``unit`` or ``units`` attribute, as a pint.Unit object.
+    :return: pint.Quantity with the data and associated unit.
     """
     with hdf5_open(file_path) as h5f:
         if data_path in h5f and isinstance(h5f[data_path], h5py.Dataset):
@@ -98,11 +95,11 @@ def get_quantity(
 
 def get_data(file_path: str, data_path: str):
     """
-    proxy to h5py_read_dataset, handling use case 'data_path' not present in the file.
-    In this case return None
+    Proxy to `h5py_read_dataset`, handling the case where `data_path` is not present in the file.
+    In this situation, return None.
 
-    :param file_path: file path location of the HDF5Dataset to read
-    :param data_path: data_path location of the HDF5Dataset to read
+    :param file_path: file path location of the HDF5 dataset to read.
+    :param data_path: data path location of the HDF5 dataset to read.
     """
     with hdf5_open(file_path) as h5f:
         if data_path in h5f:
@@ -119,20 +116,20 @@ def create_detector_dataset_from_tiff(
     relative_link: bool = True,
 ) -> tuple[h5py.VirtualSource]:
     """
-    create a series of externals datasets to tiff file (one per file) inside the 'external_dataset_group'
+    Create a series of external datasets to TIFF files (one per file) inside ``external_dataset_group``.
 
-    :param tiff_files: set of files to create virtual sources to
-    :param external_dataset_group: output HDF5 group. File must be accessible with write access (mode in 'w', 'a'...)
-    :param dtype: expected dtype of all the tiff data. If not provided will be deduced from the first dataset.
-    :param relative_link: if true create the link using relative link else use absolute path.
+    :param tiff_files: files used to create virtual sources.
+    :param external_dataset_group: output HDF5 group. The file must be opened with write access (mode 'w' or 'a').
+    :param dtype: expected dtype of all the TIFF data. If not provided it is deduced from the first dataset.
+    :param relative_link: if True create the link using a relative path; otherwise use an absolute path.
 
     .. warning::
 
-        The most robust way to create a NXtomo should go by using relative link (in order to share it with the .tif files).
-        Nevertheless there is today limitation on the resolution of the relative link with external dataset.
-        (resolution is done according to the current working directory instead of the file...).
-        The tomotools will handle it anyway but other software might not (like silx as this is a workaround and it should be handled at HDF5 level...)
-        So be aware that those links might 'appear' broken when using relative link. This won't happen when using absolute links...
+        The most robust way to create an NXtomo is to use relative links (in order to share it with the ``.tif`` files).
+        Nevertheless there is currently a limitation on how relative links are resolved for external datasets
+        (resolution is done according to the current working directory instead of the file).
+        Tomotools handles this, but other software might not (such as silx, as this is a workaround that should be handled at the HDF5 level).
+        Links might therefore appear broken when using relative paths, which will not happen when using absolute paths.
     """
     if not has_tifffile:
         raise RuntimeError("tiff file not installed")
